# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/kms/v1/secrets_svc.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/kms/v1/secrets_svc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtars/kms/v1/secrets_svc.proto\x12\x0btars.kms.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x17tars/docs/v1/docs.proto\"\x91\x02\n\tSecretRef\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\x33\n\x07purpose\x18\x02 \x01(\x0e\x32\x14.tars.kms.v1.PurposeB\x03\xe0\x41\x03R\x07purpose\x12$\n\x0bkek_version\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\nkekVersion\x12\x14\n\x05label\x18\x04 \x01(\tR\x05label\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\"\x80\x01\n\x10PutSecretRequest\x12\x33\n\x07purpose\x18\x01 \x01(\x0e\x32\x14.tars.kms.v1.PurposeB\x03\xe0\x41\x02R\x07purpose\x12!\n\tplaintext\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tplaintext\x12\x14\n\x05label\x18\x03 \x01(\tR\x05label\"=\n\x11PutSecretResponse\x12(\n\x03ref\x18\x01 \x01(\x0b\x32\x16.tars.kms.v1.SecretRefR\x03ref\"\'\n\x10GetSecretRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"`\n\x11GetSecretResponse\x12(\n\x03ref\x18\x01 \x01(\x0b\x32\x16.tars.kms.v1.SecretRefR\x03ref\x12!\n\tplaintext\x18\x02 \x01(\tB\x03\xe0\x41\x03R\tplaintext\"/\n\x18RotateResourceDekRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x1b\n\x19RotateResourceDekResponse\")\n\x12\x45raseSecretRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x15\n\x13\x45raseSecretResponse\"N\n\x17RotatePurposeKekRequest\x12\x33\n\x07purpose\x18\x01 \x01(\x0e\x32\x14.tars.kms.v1.PurposeB\x03\xe0\x41\x02R\x07purpose\"B\n\x18RotatePurposeKekResponse\x12&\n\x0coperation_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0boperationId\"\x18\n\x16RotateMasterKekRequest\"A\n\x17RotateMasterKekResponse\x12&\n\x0coperation_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0boperationId\"a\n\x0bSignRequest\x12\x33\n\x07purpose\x18\x01 \x01(\x0e\x32\x14.tars.kms.v1.PurposeB\x03\xe0\x41\x02R\x07purpose\x12\x1d\n\x07payload\x18\x02 \x01(\x0c\x42\x03\xe0\x41\x02R\x07payload\"W\n\x0cSignResponse\x12!\n\tsignature\x18\x01 \x01(\x0c\x42\x03\xe0\x41\x03R\tsignature\x12$\n\x0bkek_version\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\nkekVersion\"\x86\x01\n\rVerifyRequest\x12\x33\n\x07purpose\x18\x01 \x01(\x0e\x32\x14.tars.kms.v1.PurposeB\x03\xe0\x41\x02R\x07purpose\x12\x1d\n\x07payload\x18\x02 \x01(\x0c\x42\x03\xe0\x41\x02R\x07payload\x12!\n\tsignature\x18\x03 \x01(\x0c\x42\x03\xe0\x41\x02R\tsignature\"Q\n\x0eVerifyResponse\x12\x19\n\x05valid\x18\x01 \x01(\x08\x42\x03\xe0\x41\x03R\x05valid\x12$\n\x0bkek_version\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\nkekVersion*\x9f\x01\n\x07Purpose\x12\x17\n\x13PURPOSE_UNSPECIFIED\x10\x00\x12\x19\n\x15PURPOSE_AUDIT_SIGNING\x10\x01\x12\x10\n\x0cPURPOSE_BYOK\x10\x02\x12\x18\n\x14PURPOSE_JWKS_SIGNING\x10\x03\x12\x1a\n\x16PURPOSE_WEBHOOK_SECRET\x10\x04\x12\x18\n\x14PURPOSE_DATAPLANE_SA\x10\x05\x32\xce\n\n\x0eSecretsService\x12\xa2\x01\n\tPutSecret\x12\x1d.tars.kms.v1.PutSecretRequest\x1a\x1e.tars.kms.v1.PutSecretResponse\"V\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x13(\x01:\x03kms:\nput-secret\xa2\xb5\x18\x10Put a KMS secret\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/kms/secrets:\x01*\x12\xab\x01\n\tGetSecret\x12\x1d.tars.kms.v1.GetSecretRequest\x1a\x1e.tars.kms.v1.GetSecretResponse\"_\x90\x02\x01\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x17\x1a\x02id(\x01:\x03kms:\nget-secret\xa2\xb5\x18\x10Get a KMS secret\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/kms/secrets/{id}\x12\xe9\x01\n\x11RotateResourceDek\x12%.tars.kms.v1.RotateResourceDekRequest\x1a&.tars.kms.v1.RotateResourceDekResponse\"\x84\x01\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x17\x1a\x02id(\x01:\x03kms:\nrotate-dek\xa2\xb5\x18*Rotate the resource DEK on a stored secret\x82\xd3\xe4\x93\x02$\"\x1f/v1/kms/secrets/{id}/rotate-dek:\x01*\x12\xb2\x01\n\x0b\x45raseSecret\x12\x1f.tars.kms.v1.EraseSecretRequest\x1a .tars.kms.v1.EraseSecretResponse\"`\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x19\x1a\x02id(\x01:\x03kms:\x0c\x65rase-secret\xa2\xb5\x18\x12\x45rase a KMS secret\x82\xd3\xe4\x93\x02\x16*\x14/v1/kms/secrets/{id}\x12\xd1\x01\n\x10RotatePurposeKek\x12$.tars.kms.v1.RotatePurposeKekRequest\x1a%.tars.kms.v1.RotatePurposeKekResponse\"p\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x1b(\x01:\x03kms:\x12rotate-purpose-kek\xa2\xb5\x18\x16Rotate the purpose KEK\x82\xd3\xe4\x93\x02 \"\x1b/v1/kms/purpose-keks/rotate:\x01*\x12\xca\x01\n\x0fRotateMasterKek\x12#.tars.kms.v1.RotateMasterKekRequest\x1a$.tars.kms.v1.RotateMasterKekResponse\"l\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x1a(\x01:\x03kms:\x11rotate-master-kek\xa2\xb5\x18\x15Rotate the master KEK\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/kms/master-kek/rotate:\x01*\x12N\n\x04Sign\x12\x18.tars.kms.v1.SignRequest\x1a\x19.tars.kms.v1.SignResponse\"\x11\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x12W\n\x06Verify\x12\x1a.tars.kms.v1.VerifyRequest\x1a\x1b.tars.kms.v1.VerifyResponse\"\x14\x90\x02\x01\x8a\xb5\x18\r\n\x01\x02\x12\x08internalB\xa3\x01\n\x0f\x63om.tars.kms.v1B\x0fSecretsSvcProtoP\x01Z1github.com/tetrateio/fraser/api/tars/kms/v1;kmsv1\xa2\x02\x03TKX\xaa\x02\x0bTars.Kms.V1\xca\x02\x0bTars\\Kms\\V1\xe2\x02\x17Tars\\Kms\\V1\\GPBMetadata\xea\x02\rTars::Kms::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.kms.v1.secrets_svc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.tars.kms.v1B\017SecretsSvcProtoP\001Z1github.com/tetrateio/fraser/api/tars/kms/v1;kmsv1\242\002\003TKX\252\002\013Tars.Kms.V1\312\002\013Tars\\Kms\\V1\342\002\027Tars\\Kms\\V1\\GPBMetadata\352\002\rTars::Kms::V1'
  _globals['_SECRETREF'].fields_by_name['id']._loaded_options = None
  _globals['_SECRETREF'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_SECRETREF'].fields_by_name['purpose']._loaded_options = None
  _globals['_SECRETREF'].fields_by_name['purpose']._serialized_options = b'\340A\003'
  _globals['_SECRETREF'].fields_by_name['kek_version']._loaded_options = None
  _globals['_SECRETREF'].fields_by_name['kek_version']._serialized_options = b'\340A\003'
  _globals['_SECRETREF'].fields_by_name['created_at']._loaded_options = None
  _globals['_SECRETREF'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_SECRETREF'].fields_by_name['updated_at']._loaded_options = None
  _globals['_SECRETREF'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_PUTSECRETREQUEST'].fields_by_name['purpose']._loaded_options = None
  _globals['_PUTSECRETREQUEST'].fields_by_name['purpose']._serialized_options = b'\340A\002'
  _globals['_PUTSECRETREQUEST'].fields_by_name['plaintext']._loaded_options = None
  _globals['_PUTSECRETREQUEST'].fields_by_name['plaintext']._serialized_options = b'\340A\002'
  _globals['_GETSECRETREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETSECRETREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_GETSECRETRESPONSE'].fields_by_name['plaintext']._loaded_options = None
  _globals['_GETSECRETRESPONSE'].fields_by_name['plaintext']._serialized_options = b'\340A\003'
  _globals['_ROTATERESOURCEDEKREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_ROTATERESOURCEDEKREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_ERASESECRETREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_ERASESECRETREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_ROTATEPURPOSEKEKREQUEST'].fields_by_name['purpose']._loaded_options = None
  _globals['_ROTATEPURPOSEKEKREQUEST'].fields_by_name['purpose']._serialized_options = b'\340A\002'
  _globals['_ROTATEPURPOSEKEKRESPONSE'].fields_by_name['operation_id']._loaded_options = None
  _globals['_ROTATEPURPOSEKEKRESPONSE'].fields_by_name['operation_id']._serialized_options = b'\340A\003'
  _globals['_ROTATEMASTERKEKRESPONSE'].fields_by_name['operation_id']._loaded_options = None
  _globals['_ROTATEMASTERKEKRESPONSE'].fields_by_name['operation_id']._serialized_options = b'\340A\003'
  _globals['_SIGNREQUEST'].fields_by_name['purpose']._loaded_options = None
  _globals['_SIGNREQUEST'].fields_by_name['purpose']._serialized_options = b'\340A\002'
  _globals['_SIGNREQUEST'].fields_by_name['payload']._loaded_options = None
  _globals['_SIGNREQUEST'].fields_by_name['payload']._serialized_options = b'\340A\002'
  _globals['_SIGNRESPONSE'].fields_by_name['signature']._loaded_options = None
  _globals['_SIGNRESPONSE'].fields_by_name['signature']._serialized_options = b'\340A\003'
  _globals['_SIGNRESPONSE'].fields_by_name['kek_version']._loaded_options = None
  _globals['_SIGNRESPONSE'].fields_by_name['kek_version']._serialized_options = b'\340A\003'
  _globals['_VERIFYREQUEST'].fields_by_name['purpose']._loaded_options = None
  _globals['_VERIFYREQUEST'].fields_by_name['purpose']._serialized_options = b'\340A\002'
  _globals['_VERIFYREQUEST'].fields_by_name['payload']._loaded_options = None
  _globals['_VERIFYREQUEST'].fields_by_name['payload']._serialized_options = b'\340A\002'
  _globals['_VERIFYREQUEST'].fields_by_name['signature']._loaded_options = None
  _globals['_VERIFYREQUEST'].fields_by_name['signature']._serialized_options = b'\340A\002'
  _globals['_VERIFYRESPONSE'].fields_by_name['valid']._loaded_options = None
  _globals['_VERIFYRESPONSE'].fields_by_name['valid']._serialized_options = b'\340A\003'
  _globals['_VERIFYRESPONSE'].fields_by_name['kek_version']._loaded_options = None
  _globals['_VERIFYRESPONSE'].fields_by_name['kek_version']._serialized_options = b'\340A\003'
  _globals['_SECRETSSERVICE'].methods_by_name['PutSecret']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['PutSecret']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal\222\265\030\023(\001:\003kms:\nput-secret\242\265\030\020Put a KMS secret\202\323\344\223\002\024\"\017/v1/kms/secrets:\001*'
  _globals['_SECRETSSERVICE'].methods_by_name['GetSecret']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['GetSecret']._serialized_options = b'\220\002\001\212\265\030\r\n\001\002\022\010internal\222\265\030\027\032\002id(\001:\003kms:\nget-secret\242\265\030\020Get a KMS secret\202\323\344\223\002\026\022\024/v1/kms/secrets/{id}'
  _globals['_SECRETSSERVICE'].methods_by_name['RotateResourceDek']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['RotateResourceDek']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal\222\265\030\027\032\002id(\001:\003kms:\nrotate-dek\242\265\030*Rotate the resource DEK on a stored secret\202\323\344\223\002$\"\037/v1/kms/secrets/{id}/rotate-dek:\001*'
  _globals['_SECRETSSERVICE'].methods_by_name['EraseSecret']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['EraseSecret']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal\222\265\030\031\032\002id(\001:\003kms:\014erase-secret\242\265\030\022Erase a KMS secret\202\323\344\223\002\026*\024/v1/kms/secrets/{id}'
  _globals['_SECRETSSERVICE'].methods_by_name['RotatePurposeKek']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['RotatePurposeKek']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal\222\265\030\033(\001:\003kms:\022rotate-purpose-kek\242\265\030\026Rotate the purpose KEK\202\323\344\223\002 \"\033/v1/kms/purpose-keks/rotate:\001*'
  _globals['_SECRETSSERVICE'].methods_by_name['RotateMasterKek']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['RotateMasterKek']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal\222\265\030\032(\001:\003kms:\021rotate-master-kek\242\265\030\025Rotate the master KEK\202\323\344\223\002\036\"\031/v1/kms/master-kek/rotate:\001*'
  _globals['_SECRETSSERVICE'].methods_by_name['Sign']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['Sign']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal'
  _globals['_SECRETSSERVICE'].methods_by_name['Verify']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['Verify']._serialized_options = b'\220\002\001\212\265\030\r\n\001\002\022\010internal'
  _globals['_PURPOSE']._serialized_start=1626
  _globals['_PURPOSE']._serialized_end=1785
  _globals['_SECRETREF']._serialized_start=224
  _globals['_SECRETREF']._serialized_end=497
  _globals['_PUTSECRETREQUEST']._serialized_start=500
  _globals['_PUTSECRETREQUEST']._serialized_end=628
  _globals['_PUTSECRETRESPONSE']._serialized_start=630
  _globals['_PUTSECRETRESPONSE']._serialized_end=691
  _globals['_GETSECRETREQUEST']._serialized_start=693
  _globals['_GETSECRETREQUEST']._serialized_end=732
  _globals['_GETSECRETRESPONSE']._serialized_start=734
  _globals['_GETSECRETRESPONSE']._serialized_end=830
  _globals['_ROTATERESOURCEDEKREQUEST']._serialized_start=832
  _globals['_ROTATERESOURCEDEKREQUEST']._serialized_end=879
  _globals['_ROTATERESOURCEDEKRESPONSE']._serialized_start=881
  _globals['_ROTATERESOURCEDEKRESPONSE']._serialized_end=908
  _globals['_ERASESECRETREQUEST']._serialized_start=910
  _globals['_ERASESECRETREQUEST']._serialized_end=951
  _globals['_ERASESECRETRESPONSE']._serialized_start=953
  _globals['_ERASESECRETRESPONSE']._serialized_end=974
  _globals['_ROTATEPURPOSEKEKREQUEST']._serialized_start=976
  _globals['_ROTATEPURPOSEKEKREQUEST']._serialized_end=1054
  _globals['_ROTATEPURPOSEKEKRESPONSE']._serialized_start=1056
  _globals['_ROTATEPURPOSEKEKRESPONSE']._serialized_end=1122
  _globals['_ROTATEMASTERKEKREQUEST']._serialized_start=1124
  _globals['_ROTATEMASTERKEKREQUEST']._serialized_end=1148
  _globals['_ROTATEMASTERKEKRESPONSE']._serialized_start=1150
  _globals['_ROTATEMASTERKEKRESPONSE']._serialized_end=1215
  _globals['_SIGNREQUEST']._serialized_start=1217
  _globals['_SIGNREQUEST']._serialized_end=1314
  _globals['_SIGNRESPONSE']._serialized_start=1316
  _globals['_SIGNRESPONSE']._serialized_end=1403
  _globals['_VERIFYREQUEST']._serialized_start=1406
  _globals['_VERIFYREQUEST']._serialized_end=1540
  _globals['_VERIFYRESPONSE']._serialized_start=1542
  _globals['_VERIFYRESPONSE']._serialized_end=1623
  _globals['_SECRETSSERVICE']._serialized_start=1788
  _globals['_SECRETSSERVICE']._serialized_end=3146
# @@protoc_insertion_point(module_scope)



"""Quickstart: the smallest program that gets an LLM responding through the
Tetrate Agent Router (TARS) Python SDK. You bring an API key; the SDK lists the
catalog and uses the first available model. Override with
AGENTROUTER_QUICKSTART_MODEL. Customer and project are derived from the API
key's session -- nothing to pass.

Prerequisites (set in the environment):

    AGENTROUTER_API_KEY    a long-lived key (looks like <keyid>.<secret>) for an existing project
    AGENTROUTER_BASE_URL   optional; defaults to https://api.tetrate.ai

The prompt itself is in the code below -- edit it to ask your own question.
Install and run (from the repo root):

    pip install -e sdks/python
    python sdks/examples/python/quickstart/quickstart.py

After installing the SDK sdist, the bundled copy lives next to the package at
examples/quickstart -- run `python examples/quickstart/quickstart.py` from the
extracted tree.
"""

from __future__ import annotations

import os

from agentrouter_sdk import Client


def main() -> None:
    # Client picks up AGENTROUTER_API_KEY and AGENTROUTER_BASE_URL from the
    # environment by default.
    with Client(api_key=os.environ["AGENTROUTER_API_KEY"]) as router:
        # Pick the model. The inference handler requires a non-empty model, so
        # when AGENTROUTER_QUICKSTART_MODEL is unset we list the catalog and use
        # the first model's bare name (e.g. claude-haiku-4-5), which resolves
        # its provider server-side.
        model = os.environ.get("AGENTROUTER_QUICKSTART_MODEL", "")
        if not model:
            models = router.catalog.list_models().models
            if not models:
                raise RuntimeError(
                    "no models in catalog -- ask an admin to import a catalog bundle"
                )
            model = models[0].name

        # Edit this prompt to ask your own question.
        prompt = "Happy happy joy joy"

        # Customer and project default from the session backing the API key;
        # pass "" to let the server resolve them.
        res = router.inference.prompt("", "", prompt, model=model)

    print(f"model:      {res.model}")
    print(f"completion: {res.completion}")
    print(f"tokens:     {res.prompt_tokens} prompt / {res.completion_tokens} completion")


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/lookup/v1/lookup.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/lookup/v1/lookup.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1btars/lookup/v1/lookup.proto\x12\x0etars.lookup.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x17tars/docs/v1/docs.proto\"U\n\x19GetMCPProfileByURLRequest\x12\x19\n\x03url\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x03url\x12\x1d\n\nuser_token\x18\x02 \x01(\tR\tuserToken\"R\n\x1aGetMCPProfileByURLResponse\x12\x34\n\x07profile\x18\x01 \x01(\x0b\x32\x1a.tars.lookup.v1.MCPProfileR\x07profile\"\x93\x03\n\nMCPProfile\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x10\n\x03url\x18\x05 \x01(\tR\x03url\x12\x16\n\x06status\x18\x06 \x01(\tR\x06status\x12#\n\rerror_message\x18\x07 \x01(\tR\x0c\x65rrorMessage\x12\x30\n\x14security_policy_type\x18\x08 \x01(\tR\x12securityPolicyType\x12\x32\n\x15security_policy_value\x18\t \x01(\tR\x13securityPolicyValue\x12\x39\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"d\n ResolveRouteIdentityByKeyRequest\x12 \n\x07user_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06userId\x12\x1e\n\x06key_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x05keyId\"\xe6\x01\n!ResolveRouteIdentityByKeyResponse\x12.\n\x13\x65\x66\x66\x65\x63tive_client_id\x18\x01 \x01(\tR\x11\x65\x66\x66\x65\x63tiveClientId\x12$\n\x0eroute_owner_id\x18\x02 \x01(\tR\x0crouteOwnerId\x12(\n\x10route_owner_hash\x18\x03 \x01(\tR\x0erouteOwnerHash\x12\x17\n\x07tars_id\x18\x04 \x01(\tR\x06tarsId\x12(\n\x10is_mapped_client\x18\x05 \x01(\x08R\x0eisMappedClient2\xfa\x02\n\rLookupService\x12\xa4\x01\n\x12GetMCPProfileByURL\x12).tars.lookup.v1.GetMCPProfileByURLRequest\x1a*.tars.lookup.v1.GetMCPProfileByURLResponse\"7\x90\x02\x01\x8a\xb5\x18\n\n\x02\x02\x01\x12\x04read\x82\xd3\xe4\x93\x02 \x12\x1e/lookup/v1/mcp-profiles/by-url\x12\xbb\x01\n\x19ResolveRouteIdentityByKey\x12\x30.tars.lookup.v1.ResolveRouteIdentityByKeyRequest\x1a\x31.tars.lookup.v1.ResolveRouteIdentityByKeyResponse\"9\x90\x02\x01\x8a\xb5\x18\n\n\x02\x02\x01\x12\x04read\x82\xd3\xe4\x93\x02\"\x12 /lookup/v1/route-identity/by-key\x1a\x04\xa0\xb5\x18\x01\x42{\n\x12\x63om.tars.lookup.v1B\x0bLookupProtoP\x01\xa2\x02\x03TLX\xaa\x02\x0eTars.Lookup.V1\xca\x02\x0eTars\\Lookup\\V1\xe2\x02\x1aTars\\Lookup\\V1\\GPBMetadata\xea\x02\x10Tars::Lookup::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.lookup.v1.lookup_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.tars.lookup.v1B\013LookupProtoP\001\242\002\003TLX\252\002\016Tars.Lookup.V1\312\002\016Tars\\Lookup\\V1\342\002\032Tars\\Lookup\\V1\\GPBMetadata\352\002\020Tars::Lookup::V1'
  _globals['_GETMCPPROFILEBYURLREQUEST'].fields_by_name['url']._loaded_options = None
  _globals['_GETMCPPROFILEBYURLREQUEST'].fields_by_name['url']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST'].fields_by_name['user_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_LOOKUPSERVICE']._loaded_options = None
  _globals['_LOOKUPSERVICE']._serialized_options = b'\240\265\030\001'
  _globals['_LOOKUPSERVICE'].methods_by_name['GetMCPProfileByURL']._loaded_options = None
  _globals['_LOOKUPSERVICE'].methods_by_name['GetMCPProfileByURL']._serialized_options = b'\220\002\001\212\265\030\n\n\002\002\001\022\004read\202\323\344\223\002 \022\036/lookup/v1/mcp-profiles/by-url'
  _globals['_LOOKUPSERVICE'].methods_by_name['ResolveRouteIdentityByKey']._loaded_options = None
  _globals['_LOOKUPSERVICE'].methods_by_name['ResolveRouteIdentityByKey']._serialized_options = b'\220\002\001\212\265\030\n\n\002\002\001\022\004read\202\323\344\223\002\"\022 /lookup/v1/route-identity/by-key'
  _globals['_GETMCPPROFILEBYURLREQUEST']._serialized_start=197
  _globals['_GETMCPPROFILEBYURLREQUEST']._serialized_end=282
  _globals['_GETMCPPROFILEBYURLRESPONSE']._serialized_start=284
  _globals['_GETMCPPROFILEBYURLRESPONSE']._serialized_end=366
  _globals['_MCPPROFILE']._serialized_start=369
  _globals['_MCPPROFILE']._serialized_end=772
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST']._serialized_start=774
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST']._serialized_end=874
  _globals['_RESOLVEROUTEIDENTITYBYKEYRESPONSE']._serialized_start=877
  _globals['_RESOLVEROUTEIDENTITYBYKEYRESPONSE']._serialized_end=1107
  _globals['_LOOKUPSERVICE']._serialized_start=1110
  _globals['_LOOKUPSERVICE']._serialized_end=1488
# @@protoc_insertion_point(module_scope)



from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.cli.v1 import cli_pb2 as _cli_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PromptRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "model", "prompt", "key_id", "idempotency_key")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    PROMPT_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    IDEMPOTENCY_KEY_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    model: str
    prompt: str
    key_id: str
    idempotency_key: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., model: _Optional[str] = ..., prompt: _Optional[str] = ..., key_id: _Optional[str] = ..., idempotency_key: _Optional[str] = ...) -> None: ...

class PromptResponse(_message.Message):
    __slots__ = ("completion", "model", "dataplane_id", "prompt_tokens", "completion_tokens")
    COMPLETION_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    DATAPLANE_ID_FIELD_NUMBER: _ClassVar[int]
    PROMPT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_TOKENS_FIELD_NUMBER: _ClassVar[int]
    completion: str
    model: str
    dataplane_id: str
    prompt_tokens: int
    completion_tokens: int
    def __init__(self, completion: _Optional[str] = ..., model: _Optional[str] = ..., dataplane_id: _Optional[str] = ..., prompt_tokens: _Optional[int] = ..., completion_tokens: _Optional[int] = ...) -> None: ...

class GetDataplaneURLRequest(_message.Message):
    __slots__ = ("project_id", "customer_id")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    customer_id: str
    def __init__(self, project_id: _Optional[str] = ..., customer_id: _Optional[str] = ...) -> None: ...

class DataplaneURL(_message.Message):
    __slots__ = ("url", "customer_id", "project_id", "workspace_id", "name")
    URL_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    url: str
    customer_id: str
    project_id: str
    workspace_id: str
    name: str
    def __init__(self, url: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class GetDataplaneURLResponse(_message.Message):
    __slots__ = ("dataplane",)
    DATAPLANE_FIELD_NUMBER: _ClassVar[int]
    dataplane: DataplaneURL
    def __init__(self, dataplane: _Optional[_Union[DataplaneURL, _Mapping]] = ...) -> None: ...

class ListDataplaneURLsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListDataplaneURLsResponse(_message.Message):
    __slots__ = ("dataplanes",)
    DATAPLANES_FIELD_NUMBER: _ClassVar[int]
    dataplanes: _containers.RepeatedCompositeFieldContainer[DataplaneURL]
    def __init__(self, dataplanes: _Optional[_Iterable[_Union[DataplaneURL, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/telemetry/v1/telemetry.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/telemetry/v1/telemetry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!tars/telemetry/v1/telemetry.proto\x12\x11tars.telemetry.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x17tars/docs/v1/docs.proto\"\xe6\x03\n\x0fTelemetryConfig\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType\x12\x19\n\x08sink_url\x18\x04 \x01(\tR\x07sinkUrl\x12\x1a\n\x08protocol\x18\x05 \x01(\tR\x08protocol\x12\x1b\n\tauth_type\x18\x06 \x01(\tR\x08\x61uthType\x12\x1d\n\nauth_value\x18\x07 \x01(\tR\tauthValue\x12$\n\x0e\x61pi_key_header\x18\x08 \x01(\tR\x0c\x61piKeyHeader\x12\x18\n\x07\x65nabled\x18\t \x01(\x08R\x07\x65nabled\x12\x42\n\x0flast_checked_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rlastCheckedAt\x12\x16\n\x06status\x18\x0b \x01(\tR\x06status\x12\x39\n\ncreated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"\xdc\x03\n\x1c\x43reateTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType\x12\x1f\n\x08\x65ndpoint\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x08\x65ndpoint\x12\x1a\n\x08protocol\x18\x05 \x01(\tR\x08protocol\x12\x1b\n\tauth_type\x18\x06 \x01(\tR\x08\x61uthType\x12\x1d\n\nauth_value\x18\x07 \x01(\tR\tauthValue\x12$\n\x0e\x61pi_key_header\x18\x08 \x01(\tR\x0c\x61piKeyHeader\x12V\n\x07headers\x18\t \x03(\x0b\x32<.tars.telemetry.v1.CreateTelemetryConfigRequest.HeadersEntryR\x07headers\x12\x18\n\x07\x65nabled\x18\n \x01(\x08R\x07\x65nabled\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa8\x01\n\x1bListTelemetryConfigsRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType\x12\x18\n\x07\x65nabled\x18\x04 \x01(\tR\x07\x65nabled\"r\n\x1cListTelemetryConfigsResponse\x12<\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\".tars.telemetry.v1.TelemetryConfigR\x07\x63onfigs\x12\x14\n\x05total\x18\x02 \x01(\x05R\x05total\"\x87\x01\n\x19GetTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12 \n\tconfig_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63onfigId\"\xd6\x02\n\x1cUpdateTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12 \n\tconfig_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63onfigId\x12\x1a\n\x08\x65ndpoint\x18\x04 \x01(\tR\x08\x65ndpoint\x12\x1a\n\x08protocol\x18\x05 \x01(\tR\x08protocol\x12\x1b\n\tauth_type\x18\x06 \x01(\tR\x08\x61uthType\x12\x1d\n\nauth_value\x18\x07 \x01(\tR\tauthValue\x12$\n\x0e\x61pi_key_header\x18\x08 \x01(\tR\x0c\x61piKeyHeader\x12\x18\n\x07\x65nabled\x18\t \x01(\tR\x07\x65nabled\x12\x16\n\x06status\x18\n \x01(\tR\x06status\"\x8a\x01\n\x1c\x44\x65leteTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12 \n\tconfig_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63onfigId\"\xcc\x02\n SetProjectTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType\x12\x1f\n\x08\x65ndpoint\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x08\x65ndpoint\x12\x1a\n\x08protocol\x18\x05 \x01(\tR\x08protocol\x12\x1b\n\tauth_type\x18\x06 \x01(\tR\x08\x61uthType\x12\x1d\n\nauth_value\x18\x07 \x01(\tR\tauthValue\x12$\n\x0e\x61pi_key_header\x18\x08 \x01(\tR\x0c\x61piKeyHeader\x12\x18\n\x07\x65nabled\x18\t \x01(\x08R\x07\x65nabled\"\x93\x01\n GetProjectTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType2\xaf\x0f\n\x10TelemetryService\x12\x85\x02\n\x15\x43reateTelemetryConfig\x12/.tars.telemetry.v1.CreateTelemetryConfigRequest\x1a\".tars.telemetry.v1.TelemetryConfig\"\x96\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x13:\ttelemetry:\x06\x63reate\xa2\xb5\x18 Create a telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02@\";/v1/customers/{customer_id}/projects/{project_id}/telemetry:\x01*\x12\x8b\x02\n\x14ListTelemetryConfigs\x12..tars.telemetry.v1.ListTelemetryConfigsRequest\x1a/.tars.telemetry.v1.ListTelemetryConfigsResponse\"\x91\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x11:\ttelemetry:\x04list\xa2\xb5\x18\x1dList telemetry export configs\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02=\x12;/v1/customers/{customer_id}/projects/{project_id}/telemetry\x12\x85\x02\n\x12GetTelemetryConfig\x12,.tars.telemetry.v1.GetTelemetryConfigRequest\x1a\".tars.telemetry.v1.TelemetryConfig\"\x9c\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x10:\ttelemetry:\x03get\xa2\xb5\x18\x1dGet a telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02I\x12G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}\x12\x91\x02\n\x15UpdateTelemetryConfig\x12/.tars.telemetry.v1.UpdateTelemetryConfigRequest\x1a\".tars.telemetry.v1.TelemetryConfig\"\xa2\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x13:\ttelemetry:\x06update\xa2\xb5\x18 Update a telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02L2G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}:\x01*\x12\x82\x02\n\x15\x44\x65leteTelemetryConfig\x12/.tars.telemetry.v1.DeleteTelemetryConfigRequest\x1a\x16.google.protobuf.Empty\"\x9f\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x13:\ttelemetry:\x06\x64\x65lete\xa2\xb5\x18 Delete a telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02I*G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}\x12\xb0\x02\n\x19SetProjectTelemetryConfig\x12\x33.tars.telemetry.v1.SetProjectTelemetryConfigRequest\x1a\".tars.telemetry.v1.TelemetryConfig\"\xb9\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x18:\ttelemetry:\x0bset-project\xa2\xb5\x18\'Set the project telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02H\x1a\x43/v1/customers/{customer_id}/projects/{project_id}/telemetry/project:\x01*\x12\xb0\x02\n\x19GetProjectTelemetryConfig\x12\x33.tars.telemetry.v1.GetProjectTelemetryConfigRequest\x1a\".tars.telemetry.v1.TelemetryConfig\"\xb9\x01\x90\x02\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x18:\ttelemetry:\x0bget-project\xa2\xb5\x18\'Get the project telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02\x45\x12\x43/v1/customers/{customer_id}/projects/{project_id}/telemetry/projectB\xcc\x01\n\x15\x63om.tars.telemetry.v1B\x0eTelemetryProtoP\x01Z=github.com/tetrateio/fraser/api/tars/telemetry/v1;telemetryv1\xa2\x02\x03TTX\xaa\x02\x11Tars.Telemetry.V1\xca\x02\x11Tars\\Telemetry\\V1\xe2\x02\x1dTars\\Telemetry\\V1\\GPBMetadata\xea\x02\x13Tars::Telemetry::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.telemetry.v1.telemetry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.tars.telemetry.v1B\016TelemetryProtoP\001Z=github.com/tetrateio/fraser/api/tars/telemetry/v1;telemetryv1\242\002\003TTX\252\002\021Tars.Telemetry.V1\312\002\021Tars\\Telemetry\\V1\342\002\035Tars\\Telemetry\\V1\\GPBMetadata\352\002\023Tars::Telemetry::V1'
  _globals['_CREATETELEMETRYCONFIGREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['endpoint']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['endpoint']._serialized_options = b'\340A\002'
  _globals['_LISTTELEMETRYCONFIGSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTTELEMETRYCONFIGSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_LISTTELEMETRYCONFIGSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_LISTTELEMETRYCONFIGSREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._loaded_options = None
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._serialized_options = b'\340A\002'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._serialized_options = b'\340A\002'
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._loaded_options = None
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._serialized_options = b'\340A\002'
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['endpoint']._loaded_options = None
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['endpoint']._serialized_options = b'\340A\002'
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_TELEMETRYSERVICE'].methods_by_name['CreateTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['CreateTelemetryConfig']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\023:\ttelemetry:\006create\242\265\030 Create a telemetry export config\252\265\030\tTelemetry\202\323\344\223\002@\";/v1/customers/{customer_id}/projects/{project_id}/telemetry:\001*'
  _globals['_TELEMETRYSERVICE'].methods_by_name['ListTelemetryConfigs']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['ListTelemetryConfigs']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\021:\ttelemetry:\004list\242\265\030\035List telemetry export configs\252\265\030\tTelemetry\202\323\344\223\002=\022;/v1/customers/{customer_id}/projects/{project_id}/telemetry'
  _globals['_TELEMETRYSERVICE'].methods_by_name['GetTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['GetTelemetryConfig']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\020:\ttelemetry:\003get\242\265\030\035Get a telemetry export config\252\265\030\tTelemetry\202\323\344\223\002I\022G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}'
  _globals['_TELEMETRYSERVICE'].methods_by_name['UpdateTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['UpdateTelemetryConfig']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\023:\ttelemetry:\006update\242\265\030 Update a telemetry export config\252\265\030\tTelemetry\202\323\344\223\002L2G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}:\001*'
  _globals['_TELEMETRYSERVICE'].methods_by_name['DeleteTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['DeleteTelemetryConfig']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\023:\ttelemetry:\006delete\242\265\030 Delete a telemetry export config\252\265\030\tTelemetry\202\323\344\223\002I*G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}'
  _globals['_TELEMETRYSERVICE'].methods_by_name['SetProjectTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['SetProjectTelemetryConfig']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\030:\ttelemetry:\013set-project\242\265\030\'Set the project telemetry export config\252\265\030\tTelemetry\202\323\344\223\002H\032C/v1/customers/{customer_id}/projects/{project_id}/telemetry/project:\001*'
  _globals['_TELEMETRYSERVICE'].methods_by_name['GetProjectTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['GetProjectTelemetryConfig']._serialized_options = b'\220\002\001\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\030:\ttelemetry:\013get-project\242\265\030\'Get the project telemetry export config\252\265\030\tTelemetry\202\323\344\223\002E\022C/v1/customers/{customer_id}/projects/{project_id}/telemetry/project'
  _globals['_TELEMETRYCONFIG']._serialized_start=263
  _globals['_TELEMETRYCONFIG']._serialized_end=749
  _globals['_CREATETELEMETRYCONFIGREQUEST']._serialized_start=752
  _globals['_CREATETELEMETRYCONFIGREQUEST']._serialized_end=1228
  _globals['_CREATETELEMETRYCONFIGREQUEST_HEADERSENTRY']._serialized_start=1170
  _globals['_CREATETELEMETRYCONFIGREQUEST_HEADERSENTRY']._serialized_end=1228
  _globals['_LISTTELEMETRYCONFIGSREQUEST']._serialized_start=1231
  _globals['_LISTTELEMETRYCONFIGSREQUEST']._serialized_end=1399
  _globals['_LISTTELEMETRYCONFIGSRESPONSE']._serialized_start=1401
  _globals['_LISTTELEMETRYCONFIGSRESPONSE']._serialized_end=1515
  _globals['_GETTELEMETRYCONFIGREQUEST']._serialized_start=1518
  _globals['_GETTELEMETRYCONFIGREQUEST']._serialized_end=1653
  _globals['_UPDATETELEMETRYCONFIGREQUEST']._serialized_start=1656
  _globals['_UPDATETELEMETRYCONFIGREQUEST']._serialized_end=1998
  _globals['_DELETETELEMETRYCONFIGREQUEST']._serialized_start=2001
  _globals['_DELETETELEMETRYCONFIGREQUEST']._serialized_end=2139
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST']._serialized_start=2142
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST']._serialized_end=2474
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST']._serialized_start=2477
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST']._serialized_end=2624
  _globals['_TELEMETRYSERVICE']._serialized_start=2627
  _globals['_TELEMETRYSERVICE']._serialized_end=4594
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/secret/v1/secret.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/secret/v1/secret.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1btars/secret/v1/secret.proto\x12\x0etars.secret.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x17tars/docs/v1/docs.proto\"\x8c\x02\n\x13\x43reateSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x14\n\x05value\x18\x04 \x01(\tR\x05value\x12\x41\n\x04tags\x18\x05 \x03(\x0b\x32-.tars.secret.v1.CreateSecretRequest.TagsEntryR\x04tags\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"F\n\x14\x43reateSecretResponse\x12.\n\x06secret\x18\x01 \x01(\x0b\x32\x16.tars.secret.v1.SecretR\x06secret\"<\n\x10GetSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\"C\n\x11GetSecretResponse\x12.\n\x06secret\x18\x01 \x01(\x0b\x32\x16.tars.secret.v1.SecretR\x06secret\"\x97\x02\n\x12ListSecretsRequest\x12\x14\n\x05realm\x18\x01 \x01(\tR\x05realm\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32\x1c.tars.secret.v1.SecretStatusR\x06status\x12@\n\x04tags\x18\x03 \x03(\x0b\x32,.tars.secret.v1.ListSecretsRequest.TagsEntryR\x04tags\x12\x1b\n\tpage_size\x18\x04 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x05 \x01(\tR\tpageToken\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"o\n\x13ListSecretsResponse\x12\x30\n\x07secrets\x18\x01 \x03(\x0b\x32\x16.tars.secret.v1.SecretR\x07secrets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"?\n\x13\x44\x65leteSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\"0\n\x14\x44\x65leteSecretResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\\\n\x13RotateSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\x12\x1b\n\tnew_value\x18\x03 \x01(\tR\x08newValue\"F\n\x14RotateSecretResponse\x12.\n\x06secret\x18\x01 \x01(\x0b\x32\x16.tars.secret.v1.SecretR\x06secret\"A\n\x15ValidateSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\"D\n\x16ValidateSecretResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x14\n\x05\x65rror\x18\x02 \x01(\tR\x05\x65rror\"Z\n\x15GetSecretValueRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\x12\x17\n\x07user_id\x18\x03 \x01(\tR\x06userId\"^\n\x16GetSecretValueResponse\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12.\n\x06secret\x18\x02 \x01(\x0b\x32\x16.tars.secret.v1.SecretR\x06secret\"\xb9\x03\n\x06Secret\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x04 \x01(\tR\x05realm\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x1f\n\x0bkek_version\x18\x06 \x01(\tR\nkekVersion\x12\x34\n\x06status\x18\x07 \x01(\x0e\x32\x1c.tars.secret.v1.SecretStatusR\x06status\x12\x34\n\x04tags\x18\x08 \x03(\x0b\x32 .tars.secret.v1.Secret.TagsEntryR\x04tags\x12\x39\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\x85\x01\n\x0cSecretStatus\x12\x1d\n\x19SECRET_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14SECRET_STATUS_ACTIVE\x10\x01\x12\x19\n\x15SECRET_STATUS_REVOKED\x10\x02\x12!\n\x1dSECRET_STATUS_ROTATED_PENDING\x10\x03\x32\xa7\x08\n\rSecretService\x12\x8a\x01\n\x0c\x43reateSecret\x12#.tars.secret.v1.CreateSecretRequest\x1a$.tars.secret.v1.CreateSecretResponse\"/\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/secrets:\x01*\x12\x88\x01\n\tGetSecret\x12 .tars.secret.v1.GetSecretRequest\x1a!.tars.secret.v1.GetSecretResponse\"6\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/secrets/{name}\x12\x87\x01\n\x0bListSecrets\x12\".tars.secret.v1.ListSecretsRequest\x1a#.tars.secret.v1.ListSecretsResponse\"/\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/secrets\x12\x8e\x01\n\x0c\x44\x65leteSecret\x12#.tars.secret.v1.DeleteSecretRequest\x1a$.tars.secret.v1.DeleteSecretResponse\"3\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\x14*\x12/v1/secrets/{name}\x12\x98\x01\n\x0cRotateSecret\x12#.tars.secret.v1.RotateSecretRequest\x1a$.tars.secret.v1.RotateSecretResponse\"=\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/secrets/{name}/rotate:\x01*\x12\xa3\x01\n\x0eValidateSecret\x12%.tars.secret.v1.ValidateSecretRequest\x1a&.tars.secret.v1.ValidateSecretResponse\"B\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02 \"\x1b/v1/secrets/{name}/validate:\x01*\x12\xa1\x01\n\x0eGetSecretValue\x12%.tars.secret.v1.GetSecretValueRequest\x1a&.tars.secret.v1.GetSecretValueResponse\"@\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/secrets/{name}/value:\x01*B\xb4\x01\n\x12\x63om.tars.secret.v1B\x0bSecretProtoP\x01Z7github.com/tetrateio/fraser/api/tars/secret/v1;secretv1\xa2\x02\x03TSX\xaa\x02\x0eTars.Secret.V1\xca\x02\x0eTars\\Secret\\V1\xe2\x02\x1aTars\\Secret\\V1\\GPBMetadata\xea\x02\x10Tars::Secret::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.secret.v1.secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.tars.secret.v1B\013SecretProtoP\001Z7github.com/tetrateio/fraser/api/tars/secret/v1;secretv1\242\002\003TSX\252\002\016Tars.Secret.V1\312\002\016Tars\\Secret\\V1\342\002\032Tars\\Secret\\V1\\GPBMetadata\352\002\020Tars::Secret::V1'
  _globals['_CREATESECRETREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_CREATESECRETREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_LISTSECRETSREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_LISTSECRETSREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_SECRET_TAGSENTRY']._loaded_options = None
  _globals['_SECRET_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_SECRETSERVICE'].methods_by_name['CreateSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['CreateSecret']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002\020\"\013/v1/secrets:\001*'
  _globals['_SECRETSERVICE'].methods_by_name['GetSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['GetSecret']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002\024\022\022/v1/secrets/{name}'
  _globals['_SECRETSERVICE'].methods_by_name['ListSecrets']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['ListSecrets']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002\r\022\013/v1/secrets'
  _globals['_SECRETSERVICE'].methods_by_name['DeleteSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['DeleteSecret']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002\024*\022/v1/secrets/{name}'
  _globals['_SECRETSERVICE'].methods_by_name['RotateSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['RotateSecret']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002\036\"\031/v1/secrets/{name}/rotate:\001*'
  _globals['_SECRETSERVICE'].methods_by_name['ValidateSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['ValidateSecret']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002 \"\033/v1/secrets/{name}/validate:\001*'
  _globals['_SECRETSERVICE'].methods_by_name['GetSecretValue']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['GetSecretValue']._serialized_options = b'\220\002\001\212\265\030\013\n\002\001\002\022\005admin\252\265\030\007Secrets\202\323\344\223\002\035\"\030/v1/secrets/{name}/value:\001*'
  _globals['_SECRETSTATUS']._serialized_start=2088
  _globals['_SECRETSTATUS']._serialized_end=2221
  _globals['_CREATESECRETREQUEST']._serialized_start=169
  _globals['_CREATESECRETREQUEST']._serialized_end=437
  _globals['_CREATESECRETREQUEST_TAGSENTRY']._serialized_start=382
  _globals['_CREATESECRETREQUEST_TAGSENTRY']._serialized_end=437
  _globals['_CREATESECRETRESPONSE']._serialized_start=439
  _globals['_CREATESECRETRESPONSE']._serialized_end=509
  _globals['_GETSECRETREQUEST']._serialized_start=511
  _globals['_GETSECRETREQUEST']._serialized_end=571
  _globals['_GETSECRETRESPONSE']._serialized_start=573
  _globals['_GETSECRETRESPONSE']._serialized_end=640
  _globals['_LISTSECRETSREQUEST']._serialized_start=643
  _globals['_LISTSECRETSREQUEST']._serialized_end=922
  _globals['_LISTSECRETSREQUEST_TAGSENTRY']._serialized_start=382
  _globals['_LISTSECRETSREQUEST_TAGSENTRY']._serialized_end=437
  _globals['_LISTSECRETSRESPONSE']._serialized_start=924
  _globals['_LISTSECRETSRESPONSE']._serialized_end=1035
  _globals['_DELETESECRETREQUEST']._serialized_start=1037
  _globals['_DELETESECRETREQUEST']._serialized_end=1100
  _globals['_DELETESECRETRESPONSE']._serialized_start=1102
  _globals['_DELETESECRETRESPONSE']._serialized_end=1150
  _globals['_ROTATESECRETREQUEST']._serialized_start=1152
  _globals['_ROTATESECRETREQUEST']._serialized_end=1244
  _globals['_ROTATESECRETRESPONSE']._serialized_start=1246
  _globals['_ROTATESECRETRESPONSE']._serialized_end=1316
  _globals['_VALIDATESECRETREQUEST']._serialized_start=1318
  _globals['_VALIDATESECRETREQUEST']._serialized_end=1383
  _globals['_VALIDATESECRETRESPONSE']._serialized_start=1385
  _globals['_VALIDATESECRETRESPONSE']._serialized_end=1453
  _globals['_GETSECRETVALUEREQUEST']._serialized_start=1455
  _globals['_GETSECRETVALUEREQUEST']._serialized_end=1545
  _globals['_GETSECRETVALUERESPONSE']._serialized_start=1547
  _globals['_GETSECRETVALUERESPONSE']._serialized_end=1641
  _globals['_SECRET']._serialized_start=1644
  _globals['_SECRET']._serialized_end=2085
  _globals['_SECRET_TAGSENTRY']._serialized_start=382
  _globals['_SECRET_TAGSENTRY']._serialized_end=437
  _globals['_SECRETSERVICE']._serialized_start=2224
  _globals['_SECRETSERVICE']._serialized_end=3287
# @@protoc_insertion_point(module_scope)



from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.cli.v1 import cli_pb2 as _cli_pb2
from tars.common.v1 import types_pb2 as _types_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from tars.tenancy.v1 import customer_pb2 as _customer_pb2
from tars.tenancy.v1 import project_pb2 as _project_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateCustomerRequest(_message.Message):
    __slots__ = ("customer_id", "display_name", "description")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    display_name: str
    description: str
    def __init__(self, customer_id: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class GetCustomerRequest(_message.Message):
    __slots__ = ("customer_id",)
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    def __init__(self, customer_id: _Optional[str] = ...) -> None: ...

class ListCustomersRequest(_message.Message):
    __slots__ = ("page",)
    PAGE_FIELD_NUMBER: _ClassVar[int]
    page: _types_pb2.PageRequest
    def __init__(self, page: _Optional[_Union[_types_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class ListCustomersResponse(_message.Message):
    __slots__ = ("customers", "page")
    CUSTOMERS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    customers: _containers.RepeatedCompositeFieldContainer[_customer_pb2.Customer]
    page: _types_pb2.PageResponse
    def __init__(self, customers: _Optional[_Iterable[_Union[_customer_pb2.Customer, _Mapping]]] = ..., page: _Optional[_Union[_types_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class UpdateCustomerRequest(_message.Message):
    __slots__ = ("customer_id", "display_name", "description")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    display_name: str
    description: str
    def __init__(self, customer_id: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class ArchiveCustomerRequest(_message.Message):
    __slots__ = ("customer_id",)
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    def __init__(self, customer_id: _Optional[str] = ...) -> None: ...

class CreateProjectRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "display_name", "description")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    display_name: str
    description: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class GetProjectRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ListProjectsRequest(_message.Message):
    __slots__ = ("customer_id", "page")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    page: _types_pb2.PageRequest
    def __init__(self, customer_id: _Optional[str] = ..., page: _Optional[_Union[_types_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class ListProjectsResponse(_message.Message):
    __slots__ = ("projects", "page")
    PROJECTS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    projects: _containers.RepeatedCompositeFieldContainer[_project_pb2.Project]
    page: _types_pb2.PageResponse
    def __init__(self, projects: _Optional[_Iterable[_Union[_project_pb2.Project, _Mapping]]] = ..., page: _Optional[_Union[_types_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class UpdateProjectRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "display_name", "description")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    display_name: str
    description: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class ArchiveProjectRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class AddProjectMemberRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "identity_id", "role")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    identity_id: str
    role: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., identity_id: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...

class ListProjectMembersRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "page")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    page: _types_pb2.PageRequest
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., page: _Optional[_Union[_types_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class ListProjectMembersResponse(_message.Message):
    __slots__ = ("members", "page")
    MEMBERS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    members: _containers.RepeatedCompositeFieldContainer[_project_pb2.ProjectMember]
    page: _types_pb2.PageResponse
    def __init__(self, members: _Optional[_Iterable[_Union[_project_pb2.ProjectMember, _Mapping]]] = ..., page: _Optional[_Union[_types_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class UpdateProjectMemberRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "identity_id", "role")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    identity_id: str
    role: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., identity_id: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...

class RemoveProjectMemberRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "identity_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    identity_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., identity_id: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorReason(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ERROR_REASON_UNSPECIFIED: _ClassVar[ErrorReason]
    ERROR_REASON_INVALID_ARGUMENT: _ClassVar[ErrorReason]
    ERROR_REASON_UNAUTHENTICATED: _ClassVar[ErrorReason]
    ERROR_REASON_PERMISSION_DENIED: _ClassVar[ErrorReason]
    ERROR_REASON_NOT_FOUND: _ClassVar[ErrorReason]
    ERROR_REASON_ALREADY_EXISTS: _ClassVar[ErrorReason]
    ERROR_REASON_FAILED_PRECONDITION: _ClassVar[ErrorReason]
    ERROR_REASON_INTERNAL: _ClassVar[ErrorReason]
    ERROR_REASON_UNAVAILABLE: _ClassVar[ErrorReason]
    ERROR_REASON_MODEL_NOT_FOUND: _ClassVar[ErrorReason]
    ERROR_REASON_MODEL_AMBIGUOUS: _ClassVar[ErrorReason]
    ERROR_REASON_PROVIDER_NOT_FOUND: _ClassVar[ErrorReason]
    ERROR_REASON_CROSS_TENANT_DENIED: _ClassVar[ErrorReason]
    ERROR_REASON_SESSION_DEFAULT_UNRESOLVED: _ClassVar[ErrorReason]
ERROR_REASON_UNSPECIFIED: ErrorReason
ERROR_REASON_INVALID_ARGUMENT: ErrorReason
ERROR_REASON_UNAUTHENTICATED: ErrorReason
ERROR_REASON_PERMISSION_DENIED: ErrorReason
ERROR_REASON_NOT_FOUND: ErrorReason
ERROR_REASON_ALREADY_EXISTS: ErrorReason
ERROR_REASON_FAILED_PRECONDITION: ErrorReason
ERROR_REASON_INTERNAL: ErrorReason
ERROR_REASON_UNAVAILABLE: ErrorReason
ERROR_REASON_MODEL_NOT_FOUND: ErrorReason
ERROR_REASON_MODEL_AMBIGUOUS: ErrorReason
ERROR_REASON_PROVIDER_NOT_FOUND: ErrorReason
ERROR_REASON_CROSS_TENANT_DENIED: ErrorReason
ERROR_REASON_SESSION_DEFAULT_UNRESOLVED: ErrorReason
